======
bttt99
======


.. image:: https://img.shields.io/pypi/v/bttt99.svg
        :target: https://pypi.python.org/pypi/bttt99

.. image:: https://img.shields.io/travis/babykick/bttt99.svg
        :target: https://travis-ci.org/babykick/bttt99

.. image:: https://readthedocs.org/projects/bttt99/badge/?version=latest
        :target: https://bttt99.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/babykick/bttt99/shield.svg
     :target: https://pyup.io/repos/github/babykick/bttt99/
     :alt: Updates

A tool to navigate movie information

* Free software: MIT license
* Documentation: https://bttt99.readthedocs.io.


Features
--------

* Automatecally search the movie information

Usage
-----
> pip install bttt99

or

> pip install -e git+https://github.com/babykick/bttt99.git@master#egg=bttt99

> bttt99 rounders


